@@ -17,7 +17,7 @@ use Data::Object::ClassHas;
 
 extends 'Data::Object::Cli';
 
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 # ATTRIBUTES
 
@@ -473,6 +473,8 @@ method output(Str @args) {
 1;
 
 
+
+
 =encoding utf8
 
 =head1 NAME
@@ -574,23 +576,25 @@ Copyright (C) 2011-2019, Al Newkirk, et al.
 
 This is free software; you can redistribute it and/or modify it under the terms
 of the The Apache License, Version 2.0, as elucidated in the L<"license
-file"|https://github.com/iamalnewkirk/zing/blob/master/LICENSE>.
+file"|https://github.com/cpanery/zing/blob/master/LICENSE>.
 
 =head1 PROJECT
 
-L<Wiki|https://github.com/iamalnewkirk/zing/wiki>
+L<Wiki|https://github.com/cpanery/zing/wiki>
 
-L<Project|https://github.com/iamalnewkirk/zing>
+L<Project|https://github.com/cpanery/zing>
 
-L<Initiatives|https://github.com/iamalnewkirk/zing/projects>
+L<Initiatives|https://github.com/cpanery/zing/projects>
 
-L<Milestones|https://github.com/iamalnewkirk/zing/milestones>
+L<Milestones|https://github.com/cpanery/zing/milestones>
 
-L<Contributing|https://github.com/iamalnewkirk/zing/blob/master/CONTRIBUTE.md>
+L<Contributing|https://github.com/cpanery/zing/blob/master/CONTRIBUTE.md>
 
-L<Issues|https://github.com/iamalnewkirk/zing/issues>
+L<Issues|https://github.com/cpanery/zing/issues>
 
 =cut
+
+
 __DATA__
 
 zing - multi-process management system
