@@ -9,12 +9,21 @@ use registry 'Zing::Types';
 use routines;
 
 use Data::Object::Class;
+use Data::Object::ClassHas;
 
 use Zing::Logic::Timer;
 
 extends 'Zing::Process';
 
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
+
+# ATTRIBUTES
+
+has 'on_schedules' => (
+  is => 'ro',
+  isa => 'Maybe[CodeRef]',
+  opt => 1,
+);
 
 # BUILDERS
 
@@ -23,8 +32,20 @@ fun new_logic($self) {
   Zing::Logic::Timer->new(debug => $debug, process => $self)
 }
 
+# METHODS
+
+method schedules(@args) {
+  return $self if !$self->on_schedules;
+
+  my $schedules = $self->on_schedules->($self, @args);
+
+  return $schedules;
+}
+
 1;
 
+
+
 =encoding utf8
 
 =head1 NAME
@@ -99,7 +120,7 @@ This package supports the following scenarios:
   # schedule structure
   # [$interval, $queues, $message, $adjustment]
 
-  # predefined schedules
+  # predefined intervals
 
   # @annually is at 00:00 on day-of-month 1 in january
   # @daily is at 00:00 every day
@@ -130,6 +151,50 @@ C<@weekly>, C<@weekend>, C<@daily>, C<@hourly>, or C<@minute>.
 
 =cut
 
+=head1 ATTRIBUTES
+
+This package has the following attributes:
+
+=cut
+
+=head2 on_schedules
+
+  on_schedules(Maybe[CodeRef])
+
+This attribute is read-only, accepts C<(Maybe[CodeRef])> values, and is optional.
+
+=cut
+
+=head1 METHODS
+
+This package implements the following methods:
+
+=cut
+
+=head2 schedules
+
+  schedules(Any @args) : ArrayRef[Schedule]
+
+The schedules method, when not overloaded, executes the callback in the
+L</on_schedules> attribute and expects a list of crontab schedules to be
+processed.
+
+=over 4
+
+=item schedules example #1
+
+  my $timer = Zing::Timer->new(
+    on_schedules => sub {
+      [['@hourly', ['tasks'], { do => 1 }]]
+    },
+  );
+
+  $timer->schedules;
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Al Newkirk, C<awncorp@cpan.org>
@@ -140,20 +205,20 @@ Copyright (C) 2011-2019, Al Newkirk, et al.
 
 This is free software; you can redistribute it and/or modify it under the terms
 of the The Apache License, Version 2.0, as elucidated in the L<"license
-file"|https://github.com/iamalnewkirk/zing/blob/master/LICENSE>.
+file"|https://github.com/cpanery/zing/blob/master/LICENSE>.
 
 =head1 PROJECT
 
-L<Wiki|https://github.com/iamalnewkirk/zing/wiki>
+L<Wiki|https://github.com/cpanery/zing/wiki>
 
-L<Project|https://github.com/iamalnewkirk/zing>
+L<Project|https://github.com/cpanery/zing>
 
-L<Initiatives|https://github.com/iamalnewkirk/zing/projects>
+L<Initiatives|https://github.com/cpanery/zing/projects>
 
-L<Milestones|https://github.com/iamalnewkirk/zing/milestones>
+L<Milestones|https://github.com/cpanery/zing/milestones>
 
-L<Contributing|https://github.com/iamalnewkirk/zing/blob/master/CONTRIBUTE.md>
+L<Contributing|https://github.com/cpanery/zing/blob/master/CONTRIBUTE.md>
 
-L<Issues|https://github.com/iamalnewkirk/zing/issues>
+L<Issues|https://github.com/cpanery/zing/issues>
 
 =cut
