@@ -9,12 +9,21 @@ use registry 'Zing::Types';
 use routines;
 
 use Data::Object::Class;
+use Data::Object::ClassHas;
 
 use Zing::Logic::Watcher;
 
 extends 'Zing::Process';
 
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
+
+# ATTRIBUTES
+
+has 'on_scheme' => (
+  is => 'ro',
+  isa => 'Maybe[CodeRef]',
+  opt => 1,
+);
 
 # BUILDERS
 
@@ -23,8 +32,20 @@ fun new_logic($self) {
   Zing::Logic::Watcher->new(debug => $debug, process => $self)
 }
 
+# METHODS
+
+method scheme(@args) {
+  return $self if !$self->on_scheme;
+
+  my $scheme = $self->on_scheme->($self, @args);
+
+  return $scheme;
+}
+
 1;
 
+
+
 =encoding utf8
 
 =head1 NAME
@@ -130,6 +151,49 @@ automatically invoked when the process is executed.
 
 =cut
 
+=head1 ATTRIBUTES
+
+This package has the following attributes:
+
+=cut
+
+=head2 on_scheme
+
+  on_scheme(Maybe[CodeRef])
+
+This attribute is read-only, accepts C<(Maybe[CodeRef])> values, and is optional.
+
+=cut
+
+=head1 METHODS
+
+This package implements the following methods:
+
+=cut
+
+=head2 scheme
+
+  scheme(Any @args) : Scheme
+
+The scheme method, when not overloaded, executes the callback in the
+L</on_scheme> attribute and expects a process scheme to be processed.
+
+=over 4
+
+=item scheme example #1
+
+  my $watcher = Zing::Watcher->new(
+    on_scheme => sub {
+      ['MyApp::Handler', [], 1]
+    },
+  );
+
+  $watcher->scheme;
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Al Newkirk, C<awncorp@cpan.org>
@@ -140,20 +204,20 @@ Copyright (C) 2011-2019, Al Newkirk, et al.
 
 This is free software; you can redistribute it and/or modify it under the terms
 of the The Apache License, Version 2.0, as elucidated in the L<"license
-file"|https://github.com/iamalnewkirk/zing/blob/master/LICENSE>.
+file"|https://github.com/cpanery/zing/blob/master/LICENSE>.
 
 =head1 PROJECT
 
-L<Wiki|https://github.com/iamalnewkirk/zing/wiki>
+L<Wiki|https://github.com/cpanery/zing/wiki>
 
-L<Project|https://github.com/iamalnewkirk/zing>
+L<Project|https://github.com/cpanery/zing>
 
-L<Initiatives|https://github.com/iamalnewkirk/zing/projects>
+L<Initiatives|https://github.com/cpanery/zing/projects>
 
-L<Milestones|https://github.com/iamalnewkirk/zing/milestones>
+L<Milestones|https://github.com/cpanery/zing/milestones>
 
-L<Contributing|https://github.com/iamalnewkirk/zing/blob/master/CONTRIBUTE.md>
+L<Contributing|https://github.com/cpanery/zing/blob/master/CONTRIBUTE.md>
 
-L<Issues|https://github.com/iamalnewkirk/zing/issues>
+L<Issues|https://github.com/cpanery/zing/issues>
 
 =cut
